Assign number of reference times to delay and uncertainty from the sizes
.assign_allocation_from_ns(
n_used,
n_target,
n_min_delay,
n_min_retro_nowcasts,
n_required,
prop_delay
)List of number of reference times to use for delay and uncertainty
Integer indicating number reference times that will be used.
Integer indicating the target number of reference times.
Integer indicating the number needed for delay estimation.
Integer indicating the number needed for uncertainty estimation.
Integer indicating the number need for both delay and uncertainty
Numeric value <1 indicating what proportion of all reference times in the reporting triangle to be used for delay estimation.