Check target size against number of reference times available and the number required
.check_against_requirements(
n_ref_times,
n_required,
n_target,
n_min_delay,
n_min_retro_nowcasts,
scale_factor,
max_delay
)n_used Integer indicating how many reference times will be
used
Integer indicating the number of reference times available
Integer indicating the number need for both delay and uncertainty
Integer indicating the target number of reference times.
Integer indicating the number needed for delay estimation.
Integer indicating the number needed for uncertainty estimation.
Numeric value indicating the multiplicative factor on
the maximum delay to be used for estimation of delay and uncertainty.
Default is 3.