Learn R Programming

baselinenowcast (version 0.2.0)

.safelydoesit: Safe iterator

Description

Safe iterator

Usage

.safelydoesit(fun)

Value

Function that returns a list with result and error components. On success: result contains the function output and error is NULL. On failure: result is NULL and error contains the error object.

Arguments

fun

Function to wrap around