Learn R Programming

baselinenowcast (version 0.2.0)

.validate_delay: Validate the delay PMF if it is passed in

Description

Validate the delay PMF if it is passed in

Usage

.validate_delay(triangle, delay_pmf)

Value

NULL invisibly

Arguments

triangle

Matrix of values with rows indicating the time points and columns indicating the delays.

delay_pmf

Vector of length of the number of delays indicating the probability of a case being reported on a given delay.