Validate the specified number of reference times meets the minimum requirements
.validate_inputs_uncertainty(
n_ref_times,
n_min_delay,
n_history_delay,
n_retrospective_nowcasts,
n_min_retro_nowcasts = 2
)NULL, invisibly
Integer indicating the number of reference times available.
Integer indicating minimum number of reference times needed for delay estimation.
Integer indicating the number of reference times (observations) to be used in the estimate of the reporting delay, always starting from the most recent reporting delay.
Integer indicating the number of retrospective nowcast times to use for uncertainty estimation.
Integer indicating the minimum number of
reference times needed for uncertainty estimation. Default is 2.