Learn R Programming

baselinenowcast (version 0.2.0)

.validate_multiple_inputs: Validate the inputs to estimate_and_apply_uncertainty() to ensure that the reporting triangle, point nowcast matrix, and specified maximum delay are correct.

Description

Validate the inputs to estimate_and_apply_uncertainty() to ensure that the reporting triangle, point nowcast matrix, and specified maximum delay are correct.

Usage

.validate_multiple_inputs(point_nowcast_matrix, reporting_triangle)

Value

NULL, invisibly

Arguments

point_nowcast_matrix

Matrix of point nowcast predictions and observations, with rows representing the reference times and columns representing the delays.

reporting_triangle

A reporting_triangle object with rows representing reference times and columns representing delays. Can be a reporting matrix or incomplete reporting matrix. Can also be a ragged reporting triangle, where multiple columns are reported for the same row (e.g., weekly reporting of daily data).