Learn R Programming

baselinenowcast (version 0.2.0)

.validate_uncertainty: Validate the uncertainty parameters if they are passed in

Description

Validate the uncertainty parameters if they are passed in

Usage

.validate_uncertainty(triangle, uncertainty_params)

Value

NULL invisibly

Arguments

triangle

Matrix of values with rows indicating the time points and columns indicating the delays.

uncertainty_params

Vector of uncertainty parameters ordered from horizon 1 to the maximum horizon. Note that these will be reversed internally to match the ordering of the point_nowcast_matrix (where a horizon of 1 is the last entry).