A baselinenowcast_df object which contains point or probabilistic nowcasts
alongside reference dates and any additional metadata, in tidy data format.
Nowcasts are presented aggregated across delays, by reference date.
A baselinenowcast_df object. This is a data.frame subclass
containing nowcast results. See the Structure section for details on
the required columns.
A baselinenowcast_df is a data.frame with the following columns:
Dates corresponding to the reference times of the nowcast.
Numeric indicating the estimated total counts aggregated across delays at each reference date.
Integer indexing the sample from the probabilistic nowcast
distribution. If output_type = "point", this will be set to 1.
Character string indicating whether the pred_count
represents a probabilistic draw from the observation model indicated by
"samples" or whether the pred_count is a point estimate indicated by
"point".
See the corresponding reporting_triangle and
baselinenowcast() function
for more details on the required inputs to generate the object.
Main nowcasting interface functions
assert_baselinenowcast_df(),
baselinenowcast(),
baselinenowcast.data.frame(),
baselinenowcast.reporting_triangle(),
new_baselinenowcast_df()