Learn R Programming

baselinenowcast (version 0.2.0)

germany_covid19_hosp: Incident COVID-19 hospitalisations indexed by the date of positive test (reference date) and report date from Germany in 2021 and 2022.

Description

Incident COVID-19 hospitalisations indexed by the date of positive test (reference date) and report date from Germany in 2021 and 2022.

Usage

germany_covid19_hosp

Arguments

Format

A data.frame with 140,630 rows and 6 columns.

reference_date

Date of first positive COVID-19 test formatted in ISO8601 standards as YYYY-MM-DD.

location

Character string indicating the location of the case counts

age_group

Character string indicating the age group of the case counts.

delay

Integer specifying the delay, in days, between the reference date and the report date

count

Integer indicating the number of cases indexed by reference and report date.

report_date

Date of case report, formatted in ISO8601 standards as YYYY-MM-DD.

See Also

Example datasets example_downward_corr_rt, example_reporting_triangle, syn_nssp_df, syn_nssp_line_list