Combines data from a nowcast dataframe, a named list of the
strata associated with the nowcast dataframe, and a vector of reference
dates corresponding to the time column in the baselinenowcast_df
new_baselinenowcast_df(baselinenowcast_df, reference_dates, output_type)An object of class baselinenowcast_df
Data.frame containing information for multiple
draws with columns for the reference time (time), the predicted counts
(pred_count), and the draw number (draw).
Vector of reference dates corresponding to the
reference times in the baselinenowcast_df.
Character string indicating whether the output should be
samples ("samples") from the estimate with full uncertainty or whether to
return the point estimate ("point"). Default is "samples". If
"point"estimates are specified, the minimum number of reference times
needed is the number needed for delay estimation, otherwise, if
"samples" are specified, at least 2 additional reference times are
required for uncertainty estimation.
Main nowcasting interface functions
assert_baselinenowcast_df(),
baselinenowcast(),
baselinenowcast.data.frame(),
baselinenowcast.reporting_triangle(),
baselinenowcast_df-class