Learn R Programming

baselinenowcast (version 0.2.0)

print.reporting_triangle: Print a reporting_triangle object

Description

Print a reporting_triangle object

Usage

# S3 method for reporting_triangle
print(x, n_rows = 10, n_cols = 10, ...)

Value

Invisibly returns the object.

Arguments

x

A reporting_triangle object to print.

n_rows

Maximum number of rows to display. If the triangle has more rows, only the last n_rows rows are shown. Default is 10. Set to NULL to display all rows.

n_cols

Maximum number of columns to display. If the triangle has more columns, only the first n_cols columns are shown. Default is 10. Set to NULL to display all columns.

...

Additional arguments passed to print methods.

See Also

Reporting triangle construction and validation [.reporting_triangle(), [<-.reporting_triangle(), as.data.frame.reporting_triangle(), as.matrix.reporting_triangle(), as_ChainLadder_triangle(), as_reporting_triangle(), as_reporting_triangle.data.frame(), as_reporting_triangle.matrix(), as_reporting_triangle.triangle(), assert_reporting_triangle(), get_delays_from_dates(), get_delays_unit(), get_max_delay(), get_mean_delay(), get_quantile_delay(), get_reference_dates(), get_report_dates(), get_reporting_structure(), head.reporting_triangle(), is_reporting_triangle(), new_reporting_triangle(), reporting_triangle-class, summary.reporting_triangle(), tail.reporting_triangle(), truncate_to_delay(), truncate_to_quantile(), validate_reporting_triangle()