Calculate the updated rows of the expected nowcasted triangle
.calc_expectation(index, expectation, delay_prob, delay_cdf_prev, n_rows)Matrix with another set of entries corresponding to the updated values for the specified rows and column
Integer indicating the delay index
Matrix of the incomplete reporting matrix
Scalar probability for the current delay
Scalar cumulative probability up to previous delay
Number of rows in the expectation matrix