Calculate the number of retrospective nowcast times that can be used after aggregating
.calc_n_retro_nowcast_times(
list_of_obs,
n_possible_horizons,
ref_time_aggregator = identity
)n_iters Integer indicating the number of iterations, or
number of retrospective nowcast times, that have sufficient data once
aggregated to be used to generate a retrospective point nowcast.
List of matrices of truncated reporting triangles
Integer indicating the number of horizons in the retrospective reporting triangle.
Function that operates along the rows (reference
times) of the retrospective point nowcast matrix before it has been
aggregated across columns (delays). Default is identity
which does not aggregate across reference times.