Helper function to calculate various size requirements
.calculate_ns(
reporting_triangle,
max_delay,
scale_factor,
n_min_retro_nowcasts
)list of the integer sizes
A reporting_triangle object with rows representing reference times and columns representing delays. Can be a reporting matrix or incomplete reporting matrix. Can also be a ragged reporting triangle, where multiple columns are reported for the same row (e.g., weekly reporting of daily data).
Numeric value indicating the multiplicative factor on
the maximum delay to be used for estimation of delay and uncertainty.
Default is 3.
Integer indicating the minimum number of
reference times needed for uncertainty estimation. Default is 2.