Extract from one matrix only elements that are missing in another
.extract_predictions(point_nowcast_matrix, reporting_triangle)Matrix containing the elements from point_nowcast_matrix for
only the elements that are missing in reporting_triangle
Matrix of point nowcast predictions and observations, with rows representing the reference times and columns representing the delays.
A reporting_triangle object with rows representing reference times and columns representing delays. Can be a reporting matrix or incomplete reporting matrix. Can also be a ragged reporting triangle, where multiple columns are reported for the same row (e.g., weekly reporting of daily data).