Perform the allocation process
.perform_allocation_process(
reporting_triangle,
max_delay,
scale_factor,
prop_delay,
n_min_retro_nowcasts
)list of reference time allocations
A reporting_triangle object with rows representing reference times and columns representing delays. Can be a reporting matrix or incomplete reporting matrix. Can also be a ragged reporting triangle, where multiple columns are reported for the same row (e.g., weekly reporting of daily data).
Numeric value indicating the multiplicative factor on
the maximum delay to be used for estimation of delay and uncertainty.
Default is 3.
Numeric value <1 indicating what proportion of all
reference times in the reporting triangle to be used for delay
estimation. Default is 0.5.
Integer indicating the minimum number of
reference times needed for uncertainty estimation. Default is 2.