powered by
Safe iterator
.safelydoesit(fun)
Function that returns a list with result and error components. On success: result contains the function output and error is NULL. On failure: result is NULL and error contains the error object.
result
error
Function to wrap around