Checks for duplicate reference date report dates, missing columns, report dates beyond the final reference date, and missing combinations of delays and reports.
.validate_rep_tri_df(data, delays_unit)NULL, invisibly
Data.frame in long tidy form with reference dates, report dates,
and case counts, used to create a reporting_triangle object.
Character string specifying the temporal granularity of
the delays. Options are "days", "weeks", "months", "years".
Default is "days".