- point_nowcast_matrix
Matrix of point nowcast predictions and
observations, with rows representing the reference times and columns
representing the delays.
- reporting_triangle
A reporting_triangle object with rows
representing reference times and columns representing delays.
Can be a reporting matrix or incomplete reporting matrix.
Can also be a ragged reporting triangle, where multiple columns are
reported for the same row (e.g., weekly reporting of daily data).
- n_history_delay
Integer indicating the number of reference times
(observations) to be used in the estimate of the reporting delay, always
starting from the most recent reporting delay.
- n_retrospective_nowcasts
Integer indicating the number of
retrospective nowcast times to use for uncertainty estimation.
- structure
Integer or vector specifying the reporting structure.
If integer, divides columns evenly by that integer (with last possibly
truncated). If vector, the sum must not be greater than or equal to the
number of columns. Default is 1 (standard triangular structure).
- draws
Integer indicating the number of draws of the predicted
nowcast vector to generate. Default is 1000.
- delay_pmf
Vector or list of vectors of delays assumed to be indexed
starting at the first delay column in each of the matrices in
retro_reporting_triangles. If a list, must be of the same length as
retro_reporting_triangles, with elements aligning. Default is NULL.
- uncertainty_model
Function that ingests a matrix of observations and a
matrix of predictions and returns a vector that can be used to
apply uncertainty using the same error model. Default is
fit_by_horizon with arguments of obs matrix of observations and
pred the matrix of predictions that fits each column (horizon)
to a negative binomial observation model by default. The user can
specify a different fitting model by replacing the
fit_model argument in fit_by_horizon.
- uncertainty_sampler
Function that ingests a vector or matrix of
predictions and a vector of uncertainty parameters and generates draws
from the observation model. Default is sample_nb which expects
arguments pred for the vector of predictions and uncertainty parameters
for the corresponding vector of uncertainty parameters, and draws from a
negative binomial for each element of the vector.
- validate
Logical. If TRUE (default), validates the object. Set to
FALSE only when called from functions that already validated.
- ...
Additional arguments to estimate_uncertainty() and
sample_prediction().