Incident COVID-19 hospitalisations indexed by the date of positive test (reference date) and report date from Germany in 2021 and 2022.
germany_covid19_hospA data.frame with 140,630 rows and 6 columns.
Date of first positive COVID-19 test formatted in ISO8601 standards as YYYY-MM-DD.
Character string indicating the location of the case counts
Character string indicating the age group of the case counts.
Integer specifying the delay, in days, between the reference date and the report date
Integer indicating the number of cases indexed by reference and report date.
Date of case report, formatted in ISO8601 standards as YYYY-MM-DD.
Example datasets
example_downward_corr_rt,
example_reporting_triangle,
syn_nssp_df,
syn_nssp_line_list