A synthetic dataset containing the number of incident cases indexed by reference date and report date. While data of this form could be from any source, this data is meant to represent the output of pre-processing the syn_nssp_line_list dataset, which is a synthetic patient-level line list data from the United State's National Syndromic Surveillance System (NSSP).
syn_nssp_dfA data.frame with 3795 rows and 3 columns.
Date the primary event occurred (e.g. date of hospital admissions, specimen collection date, symptom onset), formatted in ISO8601 standards as YYYY-MM-DD.
Date the event was reported into the surveillance system, formatted as YYYY-MM-DD.
Number of incident events (e.g. cases) occurring on the specified reference date and reported on the report date.
Example datasets
example_downward_corr_rt,
example_reporting_triangle,
germany_covid19_hosp,
syn_nssp_line_list