For an example of how to produce a nowcast from this data, see
vignette("nssp_nowcast").
syn_nssp_line_listA data.frame with 25 rows and 8 columns.
Unique identifier for each patient
Character string indicating primary symptoms and corresponding diagnoses codes.
Character string formatted as a dictionary with indices and corresponding time stamps formatted as YYYY-MM-DD HH:MM:SS.
Character string formatted as a dictionary with indices and corresponding diagnoses codes pertaining to this diagnosis associated with that event.
Numeric indicating whether the patient was admitted (0 for no, 1 for admission).
Date-time indicating the time stamp of the the patient registering in the emergency department, in YYYY-MM-DD HH:MM:SS format.
Character string indicating the race/ethnicity of the patient.
Character string indicating the sex of the patient.
Example datasets
example_downward_corr_rt,
example_reporting_triangle,
germany_covid19_hosp,
syn_nssp_df